@@ -5,9 +5,10 @@ from dataclasses import is_dataclass
 import secrets
 from http import HTTPStatus
 
-from requests import Session, Response
+from requests import Session, Response, RequestException
+import ujson
 
-from telebox.bot.serializer import Serializer, convert_datetime_to_timestamp
+from telebox.bot.converters import DataclassConverter, get_timestamp
 from telebox.bot.errors import get_request_error, BotError, RetryAfterError
 from telebox.bot.consts import chat_member_statuses
 from telebox.bot.types.types.response_parameters import ResponseParameters
@@ -76,18 +77,25 @@ class Bot:
         token: str,
         *,
         api_url: str = API_URL,
-        force_sending: bool = False,
-        default_parse_mode: Union[str, NotSet] = NOT_SET,
-        default_timeout_secs: Union[int, float, None] = None
+        parse_mode: Union[str, NotSet] = NOT_SET,
+        timeout_secs: Union[int, float, None] = None,
+        retries: int = 0,
+        retry_delay_secs: Union[int, float] = 0,
+        wait_on_rate_limit: bool = False
     ):
+        if retries < 0:
+            raise ValueError("Number of retries cannot be less than zero!")
+
         self._session = session
         self.token = token
         self._api_url = api_url
-        self._force_sending = force_sending
-        self._default_parse_mode = default_parse_mode
-        self._default_timeout_secs = default_timeout_secs
+        self._parse_mode = parse_mode
+        self._timeout_secs = timeout_secs
+        self._retries = retries
+        self._retry_delay_secs = retry_delay_secs
+        self._wait_on_rate_limit = wait_on_rate_limit
         self._over_limit_times: dict[int, float] = {}
-        self._serializer = Serializer()
+        self._dataclass_converter = DataclassConverter()
         self._me: Optional[User] = None
 
     @property
@@ -116,7 +124,7 @@ class Bot:
         allowed_updates: Optional[list[str]] = None
     ) -> list[Update]:
         return [
-            self._serializer.get_object(data=i, class_=Update)
+            self._dataclass_converter.get_object(data=i, class_=Update)
             for i in self._send_request(
                 method="getUpdates",
                 parameters={
@@ -174,13 +182,13 @@ class Bot:
         *,
         timeout_secs: Union[int, float, None] = None
     ) -> WebhookInfo:
-        return self._serializer.get_object(
+        return self._dataclass_converter.get_object(
             data=self._send_request(method="getWebhookInfo", timeout_secs=timeout_secs),
             class_=WebhookInfo
         )
 
     def get_me(self, *, timeout_secs: Union[int, float, None] = None) -> User:
-        self._me = self._serializer.get_object(
+        self._me = self._dataclass_converter.get_object(
             data=self._send_request(method="getMe", timeout_secs=timeout_secs),
             class_=User
         )
@@ -213,7 +221,7 @@ class Bot:
                             ForceReply,
                             None] = None
     ) -> Message:
-        return self._serializer.get_object(
+        return self._dataclass_converter.get_object(
             data=self._send_request(
                 method="sendMessage",
                 parameters={
@@ -245,7 +253,7 @@ class Bot:
         disable_notification: Optional[bool] = None,
         protect_content: Optional[bool] = None
     ) -> Message:
-        return self._serializer.get_object(
+        return self._dataclass_converter.get_object(
             data=self._send_request(
                 method="forwardMessage",
                 parameters={
@@ -282,7 +290,7 @@ class Bot:
                             ForceReply,
                             None] = None
     ) -> MessageId:
-        return self._serializer.get_object(
+        return self._dataclass_converter.get_object(
             data=self._send_request(
                 method="copyMessage",
                 parameters={
@@ -324,7 +332,7 @@ class Bot:
                             ForceReply,
                             None] = None
     ) -> Message:
-        return self._serializer.get_object(
+        return self._dataclass_converter.get_object(
             data=self._send_request(
                 method="sendPhoto",
                 parameters={
@@ -369,7 +377,7 @@ class Bot:
                             ForceReply,
                             None] = None
     ) -> Message:
-        return self._serializer.get_object(
+        return self._dataclass_converter.get_object(
             data=self._send_request(
                 method="sendAudio",
                 parameters={
@@ -416,7 +424,7 @@ class Bot:
                             ForceReply,
                             None] = None
     ) -> Message:
-        return self._serializer.get_object(
+        return self._dataclass_converter.get_object(
             data=self._send_request(
                 method="sendDocument",
                 parameters={
@@ -464,7 +472,7 @@ class Bot:
                             ForceReply,
                             None] = None
     ) -> Message:
-        return self._serializer.get_object(
+        return self._dataclass_converter.get_object(
             data=self._send_request(
                 method="sendVideo",
                 parameters={
@@ -514,7 +522,7 @@ class Bot:
                             ForceReply,
                             None] = None
     ) -> Message:
-        return self._serializer.get_object(
+        return self._dataclass_converter.get_object(
             data=self._send_request(
                 method="sendAnimation",
                 parameters={
@@ -560,7 +568,7 @@ class Bot:
                             ForceReply,
                             None] = None
     ) -> Message:
-        return self._serializer.get_object(
+        return self._dataclass_converter.get_object(
             data=self._send_request(
                 method="sendVoice",
                 parameters={
@@ -602,7 +610,7 @@ class Bot:
                             ForceReply,
                             None] = None
     ) -> Message:
-        return self._serializer.get_object(
+        return self._dataclass_converter.get_object(
             data=self._send_request(
                 method="sendVideoNote",
                 parameters={
@@ -639,7 +647,7 @@ class Bot:
         allow_sending_without_reply: Optional[bool] = None
     ) -> list[Message]:
         return [
-            self._serializer.get_object(data=i, class_=Message)
+            self._dataclass_converter.get_object(data=i, class_=Message)
             for i in self._send_request(
                 method="sendMediaGroup",
                 parameters={
@@ -677,7 +685,7 @@ class Bot:
                             ForceReply,
                             None] = None
     ) -> Message:
-        return self._serializer.get_object(
+        return self._dataclass_converter.get_object(
             data=self._send_request(
                 method="sendLocation",
                 parameters={
@@ -730,7 +738,7 @@ class Bot:
             timeout_secs=timeout_secs
         )
 
-        return data if data is True else self._serializer.get_object(
+        return data if data is True else self._dataclass_converter.get_object(
             data=data,
             class_=Message
         )
@@ -755,7 +763,7 @@ class Bot:
             timeout_secs=timeout_secs
         )
 
-        return data if data is True else self._serializer.get_object(
+        return data if data is True else self._dataclass_converter.get_object(
             data=data,
             class_=Message
         )
@@ -784,7 +792,7 @@ class Bot:
                             ForceReply,
                             None] = None
     ) -> Message:
-        return self._serializer.get_object(
+        return self._dataclass_converter.get_object(
             data=self._send_request(
                 method="sendVenue",
                 parameters={
@@ -829,7 +837,7 @@ class Bot:
                             ForceReply,
                             None] = None
     ) -> Message:
-        return self._serializer.get_object(
+        return self._dataclass_converter.get_object(
             data=self._send_request(
                 method="sendContact",
                 parameters={
@@ -878,7 +886,7 @@ class Bot:
                             ForceReply,
                             None] = None
     ) -> Message:
-        return self._serializer.get_object(
+        return self._dataclass_converter.get_object(
             data=self._send_request(
                 method="sendPoll",
                 parameters={
@@ -924,7 +932,7 @@ class Bot:
                             ForceReply,
                             None] = None
     ) -> Message:
-        return self._serializer.get_object(
+        return self._dataclass_converter.get_object(
             data=self._send_request(
                 method="sendDice",
                 parameters={
@@ -966,7 +974,7 @@ class Bot:
         offset: Optional[int] = None,
         limit: Optional[int] = None
     ) -> UserProfilePhotos:
-        return self._serializer.get_object(
+        return self._dataclass_converter.get_object(
             data=self._send_request(
                 method="getUserProfilePhotos",
                 parameters={
@@ -985,7 +993,7 @@ class Bot:
         *,
         timeout_secs: Union[int, float, None] = None
     ) -> File:
-        return self._serializer.get_object(
+        return self._dataclass_converter.get_object(
             data=self._send_request(
                 method="getFile",
                 parameters={
@@ -1184,7 +1192,7 @@ class Bot:
         member_limit: Optional[int] = None,
         creates_join_request: Optional[bool] = None
     ) -> ChatInviteLink:
-        return self._serializer.get_object(
+        return self._dataclass_converter.get_object(
             data=self._send_request(
                 method="createChatInviteLink",
                 parameters={
@@ -1210,7 +1218,7 @@ class Bot:
         member_limit: Optional[int] = None,
         creates_join_request: Optional[bool] = None
     ) -> ChatInviteLink:
-        return self._serializer.get_object(
+        return self._dataclass_converter.get_object(
             data=self._send_request(
                 method="editChatInviteLink",
                 parameters={
@@ -1233,7 +1241,7 @@ class Bot:
         *,
         timeout_secs: Union[int, float, None] = None
     ) -> ChatInviteLink:
-        return self._serializer.get_object(
+        return self._dataclass_converter.get_object(
             data=self._send_request(
                 method="revokeChatInviteLink",
                 parameters={
@@ -1407,7 +1415,7 @@ class Bot:
         *,
         timeout_secs: Union[int, float, None] = None
     ) -> Chat:
-        return self._serializer.get_object(
+        return self._dataclass_converter.get_object(
             data=self._send_request(
                 method="getChat",
                 parameters={
@@ -1426,7 +1434,7 @@ class Bot:
     ) -> list[Union[ChatMemberOwner,
                     ChatMemberAdministrator]]:
         return [
-            self._serializer.get_object(data=i, class_=_CHAT_MEMBER_TYPES[i["status"]])
+            self._dataclass_converter.get_object(data=i, class_=_CHAT_MEMBER_TYPES[i["status"]])
             for i in self._send_request(
                 method="getChatAdministrators",
                 parameters={
@@ -1466,7 +1474,7 @@ class Bot:
             timeout_secs=timeout_secs
         )
 
-        return self._serializer.get_object(
+        return self._dataclass_converter.get_object(
             data=data,
             class_=_CHAT_MEMBER_TYPES[data["status"]]
         )
@@ -1507,7 +1515,7 @@ class Bot:
         timeout_secs: Union[int, float, None] = None
     ) -> list[Sticker]:
         return [
-            self._serializer.get_object(data=i, class_=Sticker)
+            self._dataclass_converter.get_object(data=i, class_=Sticker)
             for i in self._send_request(
                 method="getForumTopicIconStickers",
                 timeout_secs=timeout_secs
@@ -1523,7 +1531,7 @@ class Bot:
         icon_color: Optional[int] = None,
         icon_custom_emoji_id: Optional[str] = None
     ) -> ForumTopic:
-        return self._serializer.get_object(
+        return self._dataclass_converter.get_object(
             data=self._send_request(
                 method="createForumTopic",
                 parameters={
@@ -1685,7 +1693,7 @@ class Bot:
         language_code: Optional[str] = None
     ) -> list[BotCommand]:
         return [
-            self._serializer.get_object(data=i, class_=BotCommand)
+            self._dataclass_converter.get_object(data=i, class_=BotCommand)
             for i in self._send_request(
                 method="getMyCommands",
                 parameters={
@@ -1784,7 +1792,7 @@ class Bot:
             timeout_secs=timeout_secs
         )
 
-        return data if data is True else self._serializer.get_object(
+        return data if data is True else self._dataclass_converter.get_object(
             data=data,
             class_=Message
         )
@@ -1815,7 +1823,7 @@ class Bot:
             timeout_secs=timeout_secs
         )
 
-        return data if data is True else self._serializer.get_object(
+        return data if data is True else self._dataclass_converter.get_object(
             data=data,
             class_=Message
         )
@@ -1842,7 +1850,7 @@ class Bot:
             timeout_secs=timeout_secs
         )
 
-        return data if data is True else self._serializer.get_object(
+        return data if data is True else self._dataclass_converter.get_object(
             data=data,
             class_=Message
         )
@@ -1867,7 +1875,7 @@ class Bot:
             timeout_secs=timeout_secs
         )
 
-        return data if data is True else self._serializer.get_object(
+        return data if data is True else self._dataclass_converter.get_object(
             data=data,
             class_=Message
         )
@@ -1880,7 +1888,7 @@ class Bot:
         timeout_secs: Union[int, float, None] = None,
         reply_markup: Optional[InlineKeyboardMarkup] = None
     ) -> Poll:
-        return self._serializer.get_object(
+        return self._dataclass_converter.get_object(
             data=self._send_request(
                 method="stopPoll",
                 parameters={
@@ -1926,7 +1934,7 @@ class Bot:
                             ForceReply,
                             None] = None
     ) -> Message:
-        return self._serializer.get_object(
+        return self._dataclass_converter.get_object(
             data=self._send_request(
                 method="sendSticker",
                 parameters={
@@ -1950,7 +1958,7 @@ class Bot:
         *,
         timeout_secs: Union[int, float, None] = None
     ) -> StickerSet:
-        return self._serializer.get_object(
+        return self._dataclass_converter.get_object(
             data=self._send_request(
                 method="getStickerSet",
                 parameters={
@@ -1968,7 +1976,7 @@ class Bot:
         timeout_secs: Union[int, float, None] = None
     ) -> list[Sticker]:
         return [
-            self._serializer.get_object(data=i, class_=Sticker)
+            self._dataclass_converter.get_object(data=i, class_=Sticker)
             for i in self._send_request(
                 method="getCustomEmojiStickers",
                 parameters={
@@ -1985,7 +1993,7 @@ class Bot:
         *,
         timeout_secs: Union[int, float, None] = None
     ) -> File:
-        return self._serializer.get_object(
+        return self._dataclass_converter.get_object(
             data=self._send_request(
                 method="uploadStickerFile",
                 parameters={
@@ -2134,7 +2142,7 @@ class Bot:
         *,
         timeout_secs: Union[int, float, None] = None
     ) -> SentWebAppMessage:
-        return self._serializer.get_object(
+        return self._dataclass_converter.get_object(
             data=self._send_request(
                 method="answerWebAppQuery",
                 parameters={
@@ -2179,7 +2187,7 @@ class Bot:
         allow_sending_without_reply: Optional[bool] = None,
         reply_markup: Optional[InlineKeyboardMarkup] = None
     ) -> Message:
-        return self._serializer.get_object(
+        return self._dataclass_converter.get_object(
             data=self._send_request(
                 method="sendInvoice",
                 parameters={
@@ -2336,7 +2344,7 @@ class Bot:
         allow_sending_without_reply: Optional[bool] = None,
         reply_markup: Optional[InlineKeyboardMarkup] = None
     ) -> Message:
-        return self._serializer.get_object(
+        return self._dataclass_converter.get_object(
             data=self._send_request(
                 method="sendGame",
                 parameters={
@@ -2380,7 +2388,7 @@ class Bot:
             timeout_secs=timeout_secs
         )
 
-        return data if data is True else self._serializer.get_object(
+        return data if data is True else self._dataclass_converter.get_object(
             data=data,
             class_=Message
         )
@@ -2395,7 +2403,7 @@ class Bot:
         inline_message_id: Optional[str] = None
     ) -> list[GameHighScore]:
         return [
-            self._serializer.get_object(data=i, class_=GameHighScore)
+            self._dataclass_converter.get_object(data=i, class_=GameHighScore)
             for i in self._send_request(
                 method="getGameHighScores",
                 parameters={
@@ -2418,14 +2426,24 @@ class Bot:
         parameters = parameters or {}
         url = self._get_api_url(method)
         data, files = self._get_prepared_parameters(parameters)
-        timeout_secs = timeout_secs or self._default_timeout_secs
+        timeout_secs = timeout_secs or self._timeout_secs
         chat_id = over_limit_chat_id = parameters.get("chat_id")
 
         if not isinstance(over_limit_chat_id, int):
             over_limit_chat_id = None
 
+        retries = 0
+
         while True:
-            response = self._session.post(url, json=data, files=files, timeout=timeout_secs)
+            try:
+                response = self._session.post(url, data=data, files=files, timeout=timeout_secs)
+            except RequestException:
+                if retries == self._retries:
+                    raise
+
+                retries += 1
+                time.sleep(self._retry_delay_secs)
+                continue
 
             try:
                 return self._process_response(response, method, parameters)
@@ -2435,7 +2453,7 @@ class Bot:
                 if over_limit_chat_id is not None:
                     self._over_limit_times[chat_id] = time.monotonic() + error.retry_after
 
-                if not self._force_sending:
+                if not self._wait_on_rate_limit:
                     raise
 
                 time.sleep(error.retry_after)
@@ -2446,8 +2464,8 @@ class Bot:
     def _get_parse_mode(self, parse_mode: Union[str, None, NotSet]) -> Optional[str]:
         if parse_mode is not NOT_SET:
             return parse_mode
-        elif self._default_parse_mode is not NOT_SET:
-            return self._default_parse_mode
+        elif self._parse_mode is not NOT_SET:
+            return self._parse_mode
 
     def _get_prepared_parameters(
         self,
@@ -2456,39 +2474,50 @@ class Bot:
         data = {}
         files = []
 
-        for name, value in parameters.items():
-            if value is None:
+        for name, parameter in parameters.items():
+            if parameter is None:
                 continue
 
-            if isinstance(value, InputFile):
-                files.append((name, (value.name or secrets.token_urlsafe(16), value.content)))
+            if isinstance(parameter, InputFile):
+                files.append((
+                    name,
+                    (
+                        parameter.name or secrets.token_urlsafe(16),
+                        parameter.content
+                    )
+                ))
             else:
-                data[name] = self._get_prepared_parameter(value)
+                parameter = self._get_prepared_parameter(parameter)
+
+                if isinstance(parameter, (dict, list)):
+                    data[name] = ujson.dumps(parameter)
+                else:
+                    data[name] = parameter
 
         return data, files
 
-    def _get_prepared_parameter(self, value: Any) -> Any:
-        if is_dataclass(value):
-            return self._serializer.get_data(value)
-        elif isinstance(value, datetime):
-            return convert_datetime_to_timestamp(value)
-        elif isinstance(value, list):
-            return self._get_prepared_list_parameter(value)
+    def _get_prepared_parameter(self, parameter: Any) -> Any:
+        if is_dataclass(parameter):
+            return self._dataclass_converter.get_data(parameter)
+        elif isinstance(parameter, datetime):
+            return get_timestamp(parameter)
+        elif isinstance(parameter, list):
+            return self._get_prepared_list_parameter(parameter)
 
-        return value
+        return parameter
 
-    def _get_prepared_list_parameter(self, value: list[Any]) -> list[Any]:
-        prepared_value = []
+    def _get_prepared_list_parameter(self, parameter: list[Any]) -> list[Any]:
+        prepared_parameter = []
 
-        for i in value:
+        for i in parameter:
             if isinstance(i, list):
                 result = self._get_prepared_list_parameter(i)
             else:
                 result = self._get_prepared_parameter(i)
 
-            prepared_value.append(result)
+            prepared_parameter.append(result)
 
-        return prepared_value
+        return prepared_parameter
 
     def _process_response(
         self,
@@ -2504,7 +2533,7 @@ class Bot:
             except KeyError:
                 response_parameters = None
             else:
-                response_parameters = self._serializer.get_object(
+                response_parameters = self._dataclass_converter.get_object(
                     data=response_parameter_data,
                     class_=ResponseParameters
                 )
@@ -2535,16 +2564,20 @@ class TelegramBotContext:
         *,
         get_me: bool = True,
         api_url: str = API_URL,
-        force_sending: bool = False,
-        default_parse_mode: Union[str, NotSet] = NOT_SET,
-        default_timeout_secs: Union[int, float, None] = None
+        parse_mode: Union[str, NotSet] = NOT_SET,
+        timeout_secs: Union[int, float, None] = None,
+        retries: int = 0,
+        retry_delay_secs: Union[int, float] = 0,
+        wait_on_rate_limit: bool = False
     ):
         self._token = token
         self._get_me = get_me
         self._api_url = api_url
-        self._force_sending = force_sending
-        self._default_parse_mode = default_parse_mode
-        self._default_timeout_secs = default_timeout_secs
+        self._parse_mode = parse_mode
+        self._timeout_secs = timeout_secs
+        self._retries = retries
+        self._retry_delay_secs = retry_delay_secs
+        self._wait_on_rate_limit = wait_on_rate_limit
         self._session: Optional[Session] = None
 
     def __enter__(self) -> Bot:
@@ -2553,9 +2586,11 @@ class TelegramBotContext:
             self._session,
             token=self._token,
             api_url=self._api_url,
-            force_sending=self._force_sending,
-            default_parse_mode=self._default_parse_mode,
-            default_timeout_secs=self._default_timeout_secs
+            parse_mode=self._parse_mode,
+            timeout_secs=self._timeout_secs,
+            retries=self._retries,
+            retry_delay_secs=self._retry_delay_secs,
+            wait_on_rate_limit=self._wait_on_rate_limit
         )
 
         if self._get_me:
@@ -2572,15 +2607,19 @@ def get_bot(
     *,
     get_me: bool = True,
     api_url: str = API_URL,
-    force_sending: bool = False,
-    default_parse_mode: Union[str, NotSet] = NOT_SET,
-    default_timeout_secs: Union[int, float, None] = None
+    parse_mode: Union[str, NotSet] = NOT_SET,
+    timeout_secs: Union[int, float, None] = None,
+    retries: int = 0,
+    retry_delay_secs: Union[int, float] = 0,
+    wait_on_rate_limit: bool = False
 ) -> TelegramBotContext:
     return TelegramBotContext(
         token,
         get_me=get_me,
         api_url=api_url,
-        force_sending=force_sending,
-        default_parse_mode=default_parse_mode,
-        default_timeout_secs=default_timeout_secs
+        parse_mode=parse_mode,
+        timeout_secs=timeout_secs,
+        retries=retries,
+        retry_delay_secs=retry_delay_secs,
+        wait_on_rate_limit=wait_on_rate_limit
     )
