@@ -4,7 +4,7 @@ from telebox.bot.types.type import Type
 from telebox.bot.types.types.location import Location
 
 
-@dataclass(unsafe_hash=True)
+@dataclass(eq=False)
 class ChatLocation(Type):
     location: Location
     address: str
