@@ -5,7 +5,7 @@ from telebox.bot.consts import chat_member_statuses
 from telebox.bot.types.types.user import User
 
 
-@dataclass(unsafe_hash=True)
+@dataclass(eq=False)
 class ChatMemberLeft(Type):
     user: User
     status: str = chat_member_statuses.LEFT
