@@ -3,7 +3,7 @@ from dataclasses import dataclass
 from telebox.bot.types.type import Type
 
 
-@dataclass(unsafe_hash=True)
+@dataclass(eq=False)
 class ChatPhoto(Type):
     small_file_id: str
     small_file_unique_id: str
