@@ -5,7 +5,7 @@ from telebox.bot.types.type import Type
 from telebox.bot.types.types.shipping_address import ShippingAddress
 
 
-@dataclass(unsafe_hash=True)
+@dataclass(eq=False)
 class OrderInfo(Type):
     name: Optional[str] = None
     phone_number: Optional[str] = None
