@@ -4,7 +4,7 @@ from telebox.bot.types.type import Type
 from telebox.bot.consts import passport_element_error_sources
 
 
-@dataclass(unsafe_hash=True)
+@dataclass(eq=False)
 class PassportElementErrorSelfie(Type):
     type: str
     file_hash: str
