@@ -4,7 +4,7 @@ from telebox.bot.types.type import Type
 from telebox.bot.types.types.user import User
 
 
-@dataclass(unsafe_hash=True)
+@dataclass(eq=False)
 class ProximityAlertTriggered(Type):
     traveler: User
     watcher: User
