@@ -4,7 +4,7 @@ from typing import Literal, Optional
 from telebox.bot.types.type import Type
 
 
-@dataclass(unsafe_hash=True)
+@dataclass(eq=False)
 class ReplyKeyboardRemove(Type):
     remove_keyboard: Literal[True] = True
     selective: Optional[bool] = None
