@@ -4,6 +4,6 @@ from telebox.bot.types.type import Type
 from telebox.bot.types.types.user import User
 
 
-@dataclass(unsafe_hash=True)
+@dataclass(eq=False)
 class VideoChatParticipantsInvited(Type):
     users: list[User]
