@@ -1,10 +1,10 @@
-from .telegram_bot import ContextTelegramBot
+from .bot import ContextBot
 from .state_machine import ContextStateMachine
 from .vars import event_context, event_handler_context, error_handler_context
 
 
 __all__ = [
-    "ContextTelegramBot",
+    "ContextBot",
     "ContextStateMachine",
     "event_context",
     "event_handler_context",
