@@ -11,11 +11,6 @@ class StateMachineError(TeleboxError):
     pass
 
 
-@dataclass
-class StateExistsError(StateMachineError):
-    state: State
-
-
 @dataclass
 class StateNameExistsError(StateMachineError):
     state_name: str
