@@ -5,7 +5,7 @@ class StateMagazine:
 
     def __init__(self, states: list[str]):
         if not states:
-            raise ValueError("State magazine can't be empty!")
+            raise ValueError("State magazine cannot be empty!")
 
         self._states = states[:]
 
