@@ -2,7 +2,9 @@ from .not_set import NotSet, NOT_SET
 from .named_set import NamedSet
 from .callback_data_builders import AbstractCallbackDataBuilder
 from .task_executor import TaskExecutor
+from .thread_pool import ThreadPool
 from .env import Env
+from .text import get_html_text, get_markdown_text
 
 
 __all__ = [
@@ -11,5 +13,8 @@ __all__ = [
     "NamedSet",
     "AbstractCallbackDataBuilder",
     "TaskExecutor",
-    "Env"
+    "ThreadPool",
+    "Env",
+    "get_html_text",
+    "get_markdown_text"
 ]
